# Course Description

In this course at TTLMakerspace, you will go from beginner to practical working knowledge of designing and modeling in 2D, and the operation of a laser for etching and cutting a variety of materials.

Starting with desktop versions of lasers you’ll work your way through lessons and projects up to the industrial ThunderLaser cutter.

Schedule:
Six three-hour weekly classes, Tuesdays 6pm to 9pm


## Outcomes:
At the end of this course you will have achieved the following goals:
* A complete understanding of the steps needed to go from concept to completed project
* Familiarity with the properties of a variety of materials - woods, plastics, textiles
* Experience and comprehension of the most important principles of CAD modeling for constructing with laser cut parts
* Setting speeds and power levels
* Full understanding of the most common etching and cutting operations
* Experience creating tool paths with Lightburn software
* Setting up materials and performing operations
* Machine maintenance and Safety

Following this course, you’ll be certified to use desktop lasers, and book time with the industrial laser at TTLMakerspace (with your membership). You will also be able to join the growing community of TTL Makers sharing Laser knowledge on our Discord community.

Useful for: signs, gifts, personalizing anything, stamp-making, organizer, decorative items, lanterns

# What To Expect

## Week 1 - Get To Know Lasers

* Become familiar with the types of lasers including diode and CO2 based.
* Understand fundamental principles of the hardware
* Introduction to Lightburn software

Concepts Covered:

* 3 types of operations - cut, score, engrave
Intensity and Speed settings
* 3 coordinate systems - work area, current position, user position
* Job Origin

![Week1](./class1.png)

**Exercise 1** - Learn to connect to the laser from software and troubleshoot issues. Tour all of the tools available and experiment between the design and control sides of the software. 

**Exercise 2** - Master intensity/speed settings to create a small papercraft project with cutting and scoring

**Exercise 3** - Engrave your first image on wood

---
## Week 2 - Helpful tools & Materials

Having gotten the basics of controlling a laser, we learn by practical lessons how the laser reacts differently to various types of materials. We build practical tools that we can use in all of our projects for getting the ideal settings.

* Build useful tools, including a speed/power grid
* Make templates for multiple materials
* Learn to create a library of material settings
* Learn more advanced features of Lightburn
* Learn to work with images

Concepts Covered:

* Linear arrays
* Alignment tools
* Shape Properties
* Cut and Art Libraries
* Raster Images

![Week2 ](./class2.png)

**Exercise 1** - Create a speed/power grid for use in dialing in settings with a variety of materials.

**Exercise 2** - Create a cut grid

**Exercise 3** - Create your own settings library, learn to save/load it.


---
## Week 3 - Using Design Software

Having become quite familiar with Lightburn, we expand our skills into incorporating features of design software packages that are not built in to the software. We learn to use vector drawing tools in ways not available in Lightburn.

* Learn to use Inkscape features not available in Lightburn
* Make a workflow between design software and Lightburn
* Understand paths, shapes, and common terms
* Set up a work environment for laser

Concepts Covered:

* File formats, vector/raster
* Custom color palettes
* Shape On Path effect
* Text On Path effect


![Coaster](./class3.png)

**Project:** Design and create a unique coaster. Working in Inkscape, learn to make patterns using paths, and produce a coaster design that you can bring into Lightburn for decorating and cutting.

---
## Week 4 - CAD for Constructables Pt. 1

Up to now we have used 2D software. In this introduction we look at the advantages of 3D software for creation of constructable projects. We learn about the parametric modeling, and how it can help us iterate on designs.

![TabsSlots](./class4.png)

* Learn to sketch and design in CAD
* Make objects that can be easily adjusted, customized, and cut on the laser

Concepts Covered:  

* Workbenches - part design, sketcher, draft
* Construction Geometry
* Constraint-based design
* Padding/Pockets
* Shape2d, exporting for laser

**Project Pt 1:** Using CAD software, make a Parametric Box capable of being dynamically resized. This can be an organizer for your week 3 project, or another box of your own design.

---
## Week 5 - CAD for Constructables 2

In this second part of CAD for lasers we learn how to design and create perfect joints and attachment points in our constructable objects.

![Box](./class5.png)

* Plan and create connection points
* Design parametric features

Concepts Covered:

* Cloning
* Sub-object Shape Binder
* Transforms


**Project Pt 2:** Using Base Model -  Building up from the base model, create and produce a fully functional, completely customizable box.


---
## Week 6 - Foldables and Bendables

Expand our knowledge of constructable shapes into the wide world of bendable materials - papercraft, textiles, and leather.

![Lantern](./class6.png)

* Learn to use a Sheetmetal workbench for a variety of designs 
* Plan fold lines, tabs, and other bendable features
* Living Hinge
* Using adhesives, fastening techniques

Concepts Covered:

* Sheetmetal workbench
* K-factor
* Mitres, bends, extensions

**Project Paper Lantern:** Create a paper lantern. Working between CAD and Lightburn, produce a papercraft lantern complete with attachment points and fold lines.

----

### During the program:

To complete the program, you must complete all assignments and demonstrate proficiency.
Make arrangements to catch up missed classes.
Use the small machines to practice (subject to availability/classes)

Following week 3, you can practice on the CO2 laser with supervision (subject to availability)

If you hit a snag, let me know!

### Following the program:

* Three hours of free Laser time (no membership required, must be used within six weeks)

* With membership, can use small machines at any time.
* Members book time on large Laser through Cobot, $20/hr
* Run your file by us to avoid disappointment!


### Tips For Success:

* Practice! Use the small machines.
* Make your own files
* Have a project in mind, but don’t miss important concepts by being focus-locked on it.